@@ -393,6 +393,25 @@ void __fastcall TPreferencesF::Advanced_CloseAllAutoClick(TObject *Sender)
     MainF->M_Options_CloseAllAuto->Checked=Advanced_CloseAllAuto->Checked;
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TPreferencesF::Advanced_InformVersionClick(TObject *Sender)
+{
+    if (Advanced_InformVersion->Checked)
+        Prefs->Config(__T("InformVersion"), 1)=__T("1");
+    else
+        Prefs->Config(__T("InformVersion"), 1)=__T("0");
+}
+
+//---------------------------------------------------------------------------
+void __fastcall TPreferencesF::Advanced_InformTimestampClick(TObject *Sender)
+
+{
+    if (Advanced_InformTimestamp->Checked)
+        Prefs->Config(__T("InformTimestamp"), 1)=__T("1");
+    else
+        Prefs->Config(__T("InformTimestamp"), 1)=__T("0");
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TPreferencesF::Language_NewClick(TObject *Sender)
 {
@@ -524,6 +543,8 @@ void __fastcall TPreferencesF::Setup_AdvancedShow(TObject *Sender)
     CB_ShowToolBar->Checked=Prefs->Config(__T("ShowToolBar")).To_int32s();
     CB_ShowMenu->Checked=Prefs->Config(__T("ShowMenu")).To_int32s();
     Advanced_CloseAllAuto->Checked=Prefs->Config(__T("CloseAllAuto")).To_int32s();
+    Advanced_InformVersion->Checked=Prefs->Config(__T("InformVersion")).To_int32s();
+    Advanced_InformTimestamp->Checked=Prefs->Config(__T("InformTimestamp")).To_int32s();
 }
 
 //---------------------------------------------------------------------------
@@ -621,6 +642,8 @@ void __fastcall TPreferencesF::GUI_Configure()
     CB_ShowToolBar->Caption=Prefs->Translate(__T("Show toolbar")).c_str();
     CB_ShowMenu->Caption=Prefs->Translate(__T("Show menu")).c_str();
     Advanced_CloseAllAuto->Caption=Prefs->Translate(__T("Close all before open")).c_str();
+    Advanced_InformVersion->Caption=Prefs->Translate(__T("Add version to text output")).c_str();
+    Advanced_InformTimestamp->Caption=Prefs->Translate(__T("Add creation date to text output")).c_str();
     //-Language
     Language_Caption->Caption=Prefs->Translate(__T("Choose language")).c_str();
     Language_Edit->Caption=(Prefs->Translate(__T("Edit"))+__T("...")).c_str();
